@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2021, Free Software Foundation, Inc.
+Copyright (C) 2015-2022 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -183,6 +183,9 @@ gal_fits_hdu_open_format(char *filename, char *hdu, int img0_tab1);
 /**************************************************************/
 /**********            Header keywords             ************/
 /**************************************************************/
+int
+gal_fits_key_exists_fptr(fitsfile *fptr, char *keyname);
+
 void *
 gal_fits_key_img_blank(uint8_t type);
 
@@ -326,8 +329,8 @@ gal_fits_tab_info(char *filename, char *hdu, size_t *numcols,
 
 gal_data_t *
 gal_fits_tab_read(char *filename, char *hdu, size_t numrows,
-                  gal_data_t *colinfo, gal_list_sizet_t *indexll,
-                  size_t minmapsize, int quietmmap);
+                  gal_data_t *allcols, gal_list_sizet_t *indexll,
+                  size_t numthreads, size_t minmapsize, int quietmmap);
 
 void
 gal_fits_tab_write(gal_data_t *cols, gal_list_str_t *comments,
